@@ -896,11 +896,9 @@ class WordToken(models.Model):
         return False
 
     def getPreviousSpeakingRate(self):
-        if self.afterPause():
-            return 0.0
         prev_context = self.getPreviousContext()
         total_syllables = float(sum([x.getNumSylls() for x in prev_context]))
-        total_seconds = float(sum([x.getDuration() for x in prev_context]))
+        total_seconds = self.getPrevDistToPause()
         if total_seconds != 0.0:
             rate = total_syllables / total_seconds
         else:
@@ -908,11 +906,9 @@ class WordToken(models.Model):
         return rate
 
     def getFollowingSpeakingRate(self):
-        if self.beforePause():
-            return 0.0
         foll_context = self.getFollowingContext()
         total_syllables = float(sum([x.getNumSylls() for x in foll_context]))
-        total_seconds = float(sum([x.getDuration() for x in foll_context]))
+        total_seconds = self.getFollDistToPause()
         if total_seconds != 0.0:
             rate = total_syllables / total_seconds
         else:
@@ -1207,7 +1203,7 @@ class WordToken(models.Model):
                     'Word': str(self.WordType),
                     'NFormants': self.Dialog.Speaker.NumFormants,
                     'Ceiling': self.Dialog.Speaker.Ceiling,
-                    'Token': self.pk,
+                    'TokenID': self.pk,
                     'Contextual': cont,
                     'Lexical':lex,
                     'Token':tok,
@@ -1231,7 +1227,7 @@ class WordToken(models.Model):
                     'Word': str(self.WordType),
                     'NFormants': self.Dialog.Speaker.NumFormants,
                     'Ceiling': self.Dialog.Speaker.Ceiling,
-                    'Token': self.pk,
+                    'TokenID': self.pk,
                     'Contextual':cont,
                 'Token':tok,
                 'Speaker':speak}
